searchData={"items":[{"type":"module","title":"Zstream","doc":"Module for reading and writing ZIP file stream.","ref":"Zstream.html"},{"type":"function","title":"Zstream.entry/3","doc":"Creates a ZIP file entry with the given `name`.\n\nThe `enum` could be either lazy `Stream` or `List`. The elements in `enum`\nshould be of type `iodata`","ref":"Zstream.html#entry/3"},{"type":"function","title":"Options - Zstream.entry/3","doc":"* `:coder` (module | {module, list}) - The compressor that should be\n    used to encode the data. Available options are:\n\n      - `Zstream.Coder.Deflate` - use deflate compression\n\n      - `Zstream.Coder.Stored` - store without any compression\n\n      - Defaults to `Zstream.Coder.Deflate`\n\n  * `:encryption_coder` ({module, keyword}) - The encryption module that should be\n    used to encrypt the data. Available options are:\n\n      - `Zstream.EncryptionCoder.Traditional` - use tranditional zip\n      encryption scheme. `:password` key should be present in the\n      options. Example `{Zstream.EncryptionCoder.Traditional, password:\n      \"secret\"}`\n\n      - `Zstream.EncryptionCoder.None` - no encryption\n\n      - Defaults to `Zstream.EncryptionCoder.None`\n\n\n  * `:mtime` (DateTime) - File last modication time. Defaults to system local time.","ref":"Zstream.html#entry/3-options"},{"type":"function","title":"Zstream.unzip/1","doc":"Unzips file stream.\n\nReturns a new stream which emits the following tuples for each zip entry.\n\n{`:entry`, `t:Zstream.Entry.t/0`} - Indicates a new file entry.\n\n{`:data`, `t:iodata/0` | `:eof`} - one or more data tuples will be emitted for each entry. `:eof` indicates end of data tuples for current entry.","ref":"Zstream.html#unzip/1"},{"type":"function","title":"NOTES - Zstream.unzip/1","doc":"Unzip doesn't support all valid zip files. Zip file format allows\nthe writer to write the file size info after the file data, which\nallows the writer to zip streams with unknown size. But this\nprevents the reader from unzipping the file in a streaming fashion,\nbecause to find the file size one has to go to the end of the\nstream. Ironically, if you use Zstream to zip a file, the same file\ncan't be unzipped using Zstream.\n\n  * Doesn't support file which uses data descriptor header.\n  * Doesn't support encrypted file.","ref":"Zstream.html#unzip/1-notes"},{"type":"function","title":"Zstream.zip/2","doc":"Creates a ZIP file stream.\n\nEntries are consumed one by one in the given order.","ref":"Zstream.html#zip/2"},{"type":"function","title":"Options - Zstream.zip/2","doc":"* `:zip64` (boolean) - If set to `true` zip64 format is used. Zip64\n    can support files more than 4 GB in size, but not all the unzip\n    programs support this format. Defaults to `false`.","ref":"Zstream.html#zip/2-options"},{"type":"opaque","title":"Zstream.entry/0","doc":"","ref":"Zstream.html#t:entry/0"},{"type":"module","title":"Zstream.Coder.Deflate","doc":"Implements the Deflate coder.","ref":"Zstream.Coder.Deflate.html"},{"type":"function","title":"Zstream.Coder.Deflate.close/1","doc":"","ref":"Zstream.Coder.Deflate.html#close/1"},{"type":"function","title":"Zstream.Coder.Deflate.compression_method/0","doc":"","ref":"Zstream.Coder.Deflate.html#compression_method/0"},{"type":"function","title":"Zstream.Coder.Deflate.encode/2","doc":"","ref":"Zstream.Coder.Deflate.html#encode/2"},{"type":"function","title":"Zstream.Coder.Deflate.init/1","doc":"","ref":"Zstream.Coder.Deflate.html#init/1"},{"type":"module","title":"Zstream.Coder.Stored","doc":"Implements the Stored(uncompressed) coder.","ref":"Zstream.Coder.Stored.html"},{"type":"function","title":"Zstream.Coder.Stored.close/1","doc":"","ref":"Zstream.Coder.Stored.html#close/1"},{"type":"function","title":"Zstream.Coder.Stored.compression_method/0","doc":"","ref":"Zstream.Coder.Stored.html#compression_method/0"},{"type":"function","title":"Zstream.Coder.Stored.encode/2","doc":"","ref":"Zstream.Coder.Stored.html#encode/2"},{"type":"function","title":"Zstream.Coder.Stored.init/1","doc":"","ref":"Zstream.Coder.Stored.html#init/1"},{"type":"module","title":"Zstream.EncryptionCoder.None","doc":"Noop encryption.","ref":"Zstream.EncryptionCoder.None.html"},{"type":"function","title":"Zstream.EncryptionCoder.None.close/1","doc":"","ref":"Zstream.EncryptionCoder.None.html#close/1"},{"type":"function","title":"Zstream.EncryptionCoder.None.encode/2","doc":"","ref":"Zstream.EncryptionCoder.None.html#encode/2"},{"type":"function","title":"Zstream.EncryptionCoder.None.general_purpose_flag/0","doc":"","ref":"Zstream.EncryptionCoder.None.html#general_purpose_flag/0"},{"type":"function","title":"Zstream.EncryptionCoder.None.init/1","doc":"","ref":"Zstream.EncryptionCoder.None.html#init/1"},{"type":"module","title":"Zstream.EncryptionCoder.Traditional","doc":"Implements the tradition encryption.","ref":"Zstream.EncryptionCoder.Traditional.html"},{"type":"function","title":"Zstream.EncryptionCoder.Traditional.close/1","doc":"","ref":"Zstream.EncryptionCoder.Traditional.html#close/1"},{"type":"function","title":"Zstream.EncryptionCoder.Traditional.encode/2","doc":"","ref":"Zstream.EncryptionCoder.Traditional.html#encode/2"},{"type":"function","title":"Zstream.EncryptionCoder.Traditional.general_purpose_flag/0","doc":"","ref":"Zstream.EncryptionCoder.Traditional.html#general_purpose_flag/0"},{"type":"function","title":"Zstream.EncryptionCoder.Traditional.init/1","doc":"","ref":"Zstream.EncryptionCoder.Traditional.html#init/1"},{"type":"module","title":"Zstream.Entry","doc":"","ref":"Zstream.Entry.html"},{"type":"type","title":"Zstream.Entry.t/0","doc":"","ref":"Zstream.Entry.html#t:t/0"},{"type":"module","title":"Zstream.Unzip.Extra.ExtendedTimestamp","doc":"","ref":"Zstream.Unzip.Extra.ExtendedTimestamp.html"},{"type":"type","title":"Zstream.Unzip.Extra.ExtendedTimestamp.t/0","doc":"","ref":"Zstream.Unzip.Extra.ExtendedTimestamp.html#t:t/0"},{"type":"module","title":"Zstream.Unzip.Extra.Unknown","doc":"","ref":"Zstream.Unzip.Extra.Unknown.html"},{"type":"type","title":"Zstream.Unzip.Extra.Unknown.t/0","doc":"","ref":"Zstream.Unzip.Extra.Unknown.html#t:t/0"},{"type":"module","title":"Zstream.Unzip.Extra.Zip64ExtendedInformation","doc":"","ref":"Zstream.Unzip.Extra.Zip64ExtendedInformation.html"},{"type":"type","title":"Zstream.Unzip.Extra.Zip64ExtendedInformation.t/0","doc":"","ref":"Zstream.Unzip.Extra.Zip64ExtendedInformation.html#t:t/0"},{"type":"exception","title":"Zstream.Unzip.Error","doc":"","ref":"Zstream.Unzip.Error.html"},{"type":"extras","title":"Zstream","doc":"# Zstream\n\n[![CI](https://github.com/ananthakumaran/zstream/workflows/.github/workflows/ci.yml/badge.svg)](https://github.com/ananthakumaran/zstream/actions?query=workflow%3A.github%2Fworkflows%2Fci.yml)\n[![Module Version](https://img.shields.io/hexpm/v/zstream.svg)](https://hex.pm/packages/zstream)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/zstream/)\n[![Total Download](https://img.shields.io/hexpm/dt/zstream.svg)](https://hex.pm/packages/zstream)\n[![License](https://img.shields.io/hexpm/l/zstream.svg)](https://github.com/ananthakumaran/zstream/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/ananthakumaran/zstream.svg)](https://github.com/ananthakumaran/zstream/commits/master)\n\nAn Elixir library to read and write ZIP file in a streaming\nfashion. It could consume data from any stream and write to any stream\nwith constant memory overhead.","ref":"readme.html"},{"type":"extras","title":"Installation - Zstream","doc":"The package can be installed by adding `:zstream` to your list of dependencies\nin `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:zstream, \"~> 0.6\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Examples - Zstream","doc":"```elixir\nZstream.zip([\n  Zstream.entry(\"report.csv\", Stream.map(records, &CSV.dump/1)),\n  Zstream.entry(\"catfilm.mp4\", File.stream!(\"/catfilm.mp4\", [], 512), coder: Zstream.Coder.Stored)\n])\n|> Stream.into(File.stream!(\"/archive.zip\"))\n|> Stream.run\n```\n\n```elixir\nFile.stream!(\"archive.zip\", [], 512)\n|> Zstream.unzip()\n|> Enum.reduce(%{}, fn\n  {:entry, %Zstream.Entry{name: file_name} = entry}, state -> state\n  {:data, :eof}, state -> state\n  {:data, data}, state -> state\nend)\n```","ref":"readme.html#examples"},{"type":"extras","title":"Features - Zstream","doc":"","ref":"readme.html#features"},{"type":"extras","title":"zip - Zstream","doc":"* compression (deflate, stored)\n* encryption (traditional)\n* zip64","ref":"readme.html#zip"},{"type":"extras","title":"unzip - Zstream","doc":"* compression (deflate, stored)\n* zip64","ref":"readme.html#unzip"},{"type":"extras","title":"License - Zstream","doc":"Copyright (c) 2017 Anantha Kumaran\n\nThis library is MIT licensed. See the [LICENSE](https://github.com/ananthakumaran/zstream/blob/master/LICENSE) for details.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n<!--\nTypes of changes:","ref":"changelog.html"},{"type":"extras","title":"Security - Changelog","doc":"","ref":"changelog.html#security"},{"type":"extras","title":"Fixed - Changelog","doc":"","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"-->\n\n\n## [Unreleased] - yyyy-mm-dd\n\n## [0.6.6] - 2025-03-29","ref":"changelog.html#removed"},{"type":"extras","title":"Changed - Changelog","doc":"- Improve traditional encryption performance (#29)","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Changelog","ref":"changelog.html#added"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}